Smithy - Another tool in the shed
=================================

This is as straight of a clone of Rake that I could come up with.

And thus begins the rename.

`Yay Sphinx Docs <http://packages.python.org/Smithy/>`_

TODO
++++

Some things that need to be done yet:

* Task descriptions - Next on the list.
* Argument support
* Programatic addition of rules to the dependency tree.
